BatchingTimestampOracle

Struct BatchingTimestampOracle 

pub struct BatchingTimestampOracle<T> {
    inner: Arc<dyn TimestampOracle<T> + Send + Sync>,
    command_tx: UnboundedSender<Command<T>>,
}
A batching TimestampOracle backed by a TimestampOracle

This will only batch calls to read_ts because the rest of the system already naturally does batching of write-related calls via the group commit mechanism. Write-related calls are passed straight through to the backing oracle.

For read_ts calls, we have to be careful to never cache results from the backing oracle: for the timestamp to be linearized we can never return a result as of an earlier moment, but batching them up is correct because this can only make it so that we return later timestamps. Those later timestamps still fall within the duration of the read_ts call and so are linearized.

Fields

inner: Arc<dyn TimestampOracle<T> + Send + Sync>command_tx: UnboundedSender<Command<T>>

Implementations

Source

impl<T> BatchingTimestampOracle<T>
where T: Clone + Send + Sync + 'static,

pub fn new( metrics: Arc<Metrics>, oracle: Arc<dyn TimestampOracle<T> + Send + Sync>, ) -> Self

Crates a BatchingTimestampOracle that uses the given inner oracle.